@@ -46,6 +46,11 @@ class Letter(CompanyReport):
     __metaclass__ = PoolMeta
     __name__ = 'account.dunning.letter'
 
+    @classmethod
+    def execute(cls, ids, data):
+        with Transaction().set_context(address_with_party=True):
+            return super(Letter, cls).execute(ids, data)
+
     @classmethod
     def get_context(cls, records, data):
         report_context = super(Letter, cls).get_context(records, data)
@@ -92,6 +97,10 @@ class Letter(CompanyReport):
                 self.dunnings = dunnings
                 self.payments = payments
 
+            @property
+            def fees(self):
+                return {}
+
             def highest_levels(self):
                 'Yield each procedure and the highest level'
                 key = attrgetter('procedure')
